#!/bin/bash
#
# Raritan Java RRC PPPD Connect Script
#
# author: Alexander Iliev <aleksandar.iliev@bianor.com>
#
# exit codes
# 0: success
# 201: pppd already connected
# 202: not enoung arguments supplied
# 203: os not supported
# 204: chat command not found
#
# SETTINGS
MAX_WAIT=120 	#seconds
IP_GET_WAIT=10 	#seconds

# DEFAULT SETTINGS
MODEM=ttyS0
SPEED=57600
#PPPUSER=PPP
#PASSWD=PPPpw
SECRETFILE=/etc/ppp/raritan-secret
PHONE=
CALLBACK=0

# SCRIPTS AND COMMANDS
update_script=update-pppd.sh
awk="awk"
ip_get_cmd="netstat -rn"
chat_cmd=`which chat 2>/dev/null`

usage() {
	echo "usage: $0 -p PHONE_NUMBER [-m MODEM] [-s SPEED] [-t TIMEOUT] [-u USER]"
	echo "         [-pwd PWD] [-f SECRETFILE] [-chat CHATCMD] [-callback number]"
	echo ""
	echo "  MODEM is something like ttyS0 (default: modem)"
	echo "  TIMEOUT value is in seconds (default: 120)"
	echo "  SPEED is modem speed like 57600 (default: 57600)"
	echo "  CHATCMD is the path to the chat command on the system"
	echo "     NOTE: on macos x the -chat parameter is required"
	exit 202
}

parse_options() {
	while [ $# -gt 0 ]; do
		temp=$1
		case $temp in
			-m)
				shift
				MODEM=$1
				;;
			-s)
				shift
				SPEED=$1
				;;
			-t)
				shift
				MAX_WAIT=$1
				;;
			-p)
				shift
				PHONE=$1
				;;
			-u)
				shift
				PPPUSER=$1
				;;
			-pwd)
                                shift
                                PASSWD=$1
                                ;;
                        -f)
                                shift
                                SECRETFILE=$1
                                ;;
			-upd)
				shift
				update_script=$1
				;;
			-chat)
				shift
				chat_cmd=$1
				;;
			-callback)
				shift
				CALLBACK=1
				;;
			*)
				;;
		esac
		shift
	done
}

init() {
	MACOS="Darwin"
	SOLARIS="SunOS"
	LINUX="Linux"

	os=`uname`

	case $os in
        	$MACOS)
	                MODEM=cu.modem
                	;;
	        $SOLARIS)
                	MODEM=ttya
        	        ;;
	        $LINUX)
                	MODEM=ttyS0
        	        ;;
		*)
			echo "OS $os not supported"
			exit 203
			;;
	esac	
}

init

# check if already connected
$ip_get_cmd | grep ppp > /dev/null 2>&1
if [ $? != 1 ]; then
	exit 201
fi

parse_options $@

if [ -z "$chat_cmd" ]; then
	exit 204
fi

if [ -z $PHONE ]; then
	usage
fi

CHATCMD=$chat_cmd' -v ABORT "NO CARRIER" ABORT "NO DIALTONE" ABORT "ERROR" ABORT "NO ANSWER" ABORT "BUSY" ABORT "Username/Password Incorrect" TIMEOUT 40 "" "at" OK "atm0" OK "at&d3&c1" OK "atx4" OK "atdt'${PHONE}'" CONNECT ""'

# connect
. $update_script

callbackcmd=""

if [ $CALLBACK == 1 ]; then
	callbackcmd="callback 0"
fi

if [ $ISMAC == 1 -o $ISSOLARIS == 1 ]; then
	pppd call $SERVERNAME
	# check for MAX_WAIT seconds for connection
	counter=0
	$ip_get_cmd | grep ppp > /dev/null 2>&1
	while [ $? != 0 ]; do
		# exit if timeout
		if [ $counter -eq $MAX_WAIT ]; then
			exit 8
		fi
		counter=$((counter + 1))
		sleep 1
		$ip_get_cmd | grep ppp > /dev/null 2>&1
	done

	echo `$ip_get_cmd | grep ppp | $awk '{ print $1 }'`

	exit 0

else
	pppd call $SERVERNAME updetach $callbackcmd

	ret=`echo $?`

	if [ $ret = 0 ]; then

		#sleep so that detach is for sure complete
		sleep 3

		echo `$ip_get_cmd | grep ppp | $awk '{ print $1 }'`

		exit 0
	fi

	exit $ret
	
fi


